pub struct RTCIceCandidateInit {
pub candidate: String,
pub sdp_mid: Option<String>,
pub sdp_mline_index: Option<u16>,
pub username_fragment: Option<String>,
pub url: Option<String>,
}Expand description
ICECandidateInit is used to serialize ice candidates
Fields
candidate: StringThe candidate-attribute string as defined in RFC 5245.
sdp_mid: Option<String>The identifier of the “m=” section in the SDP that this candidate is associated with.
sdp_mline_index: Option<u16>The index of the “m=” section in the SDP that this candidate is associated with.
username_fragment: Option<String>The username fragment used for ICE authentication.
url: Option<String>The URL of the STUN or TURN server used to gather this candidate.
Per W3C spec, this field is only meaningful for local candidates of type
“srflx” (server reflexive) or “relay”. For other candidate types, this
field should be None.
This is a sansio extension - since gathering happens externally in the sansio architecture, the application must provide this URL when adding local candidates that were gathered from STUN/TURN servers.