StatsSelector

Enum StatsSelector 

#[non_exhaustive]
pub enum StatsSelector { None, Sender(RTCRtpSenderId), Receiver(RTCRtpReceiverId), }
Selector for filtering statistics in get_stats().

This enum corresponds to the optional selector parameter in the W3C WebRTC getStats() method. When provided, it filters the returned statistics to only those relevant to the specified sender or receiver.

W3C Reference

See The stats selection algorithm

Variants

  • None - Return all statistics for the entire connection
  • Sender - Return statistics for a specific RTP sender and referenced objects
  • Receiver - Return statistics for a specific RTP receiver and referenced objects

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

Gather stats for the whole connection.

Returns all available statistics objects including peer connection, transport, ICE candidates, codecs, data channels, and all RTP streams.



Sender(RTCRtpSenderId)

Gather stats for a specific RTP sender.

Returns:

  • All RTCOutboundRtpStreamStats for streams being sent by this sender
  • All stats objects referenced by those outbound streams (transport, codec, remote inbound stats, etc.)


Receiver(RTCRtpReceiverId)

Gather stats for a specific RTP receiver.

Returns:

  • All RTCInboundRtpStreamStats for streams being received by this receiver
  • All stats objects referenced by those inbound streams (transport, codec, remote outbound stats, etc.)